lcvtoolbox.core.schemas.huggingface.InputData
=============================================

.. currentmodule:: lcvtoolbox.core.schemas.huggingface

.. autoclass:: InputData
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~InputData.__init__
      ~InputData.clear
      ~InputData.copy
      ~InputData.fromkeys
      ~InputData.get
      ~InputData.items
      ~InputData.keys
      ~InputData.pop
      ~InputData.popitem
      ~InputData.setdefault
      ~InputData.update
      ~InputData.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~InputData.image
      ~InputData.metadata
   
   